@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015 Leandro Toledo de Souza <leandrotoeldodesouza@gmail.com>
+# Copyright (C) 2015 Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser Public License as published by
@@ -45,7 +45,7 @@ class Contact(TelegramObject):
                  first_name,
                  **kwargs):
         # Required
-        self.phone_number = phone_number
+        self.phone_number = str(phone_number)
         self.first_name = first_name
         # Optionals
         self.last_name = kwargs.get('last_name', '')
